==> haskell-statistics-0.16.3.0-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 statistics
version:              0.16.3.0
visibility:           public
id:                   statistics-0.16.3.0-FBYlBEVzdVN4oCGaNOitc
key:                  statistics-0.16.3.0-FBYlBEVzdVN4oCGaNOitc
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/haskell/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
      distributions.  (There are dozens of exotic distributions in use;
      we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
      estimation, histograms, bootstrap methods, significance testing,
      and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
      samples.

category:             Math, Statistics
abi:                  893d2e4a6877314cc783888a67d59e13
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Lognormal
    Statistics.Distribution.NegativeBinomial
    Statistics.Distribution.Normal Statistics.Distribution.Poisson
    Statistics.Distribution.StudentT Statistics.Distribution.Transform
    Statistics.Distribution.Uniform Statistics.Distribution.Weibull
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.ChiSquared
    Statistics.Test.KolmogorovSmirnov Statistics.Test.KruskalWallis
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-statistics
hs-libraries:         HSstatistics-0.16.3.0-FBYlBEVzdVN4oCGaNOitc
depends:
    aeson-2.1.2.1-FLNpA1kYfSp7ISjZQSk2AY
    async-2.2.5-GQPCMKT2tm99KQt4aOAXPc base-4.17.2.1 binary-0.8.9.1
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi deepseq-1.4.8.0
    dense-linear-algebra-0.1.0.0-7ic1fn0zCXnBLteudYdy4a
    math-functions-0.3.4.4-uXn9GKIrljDs3SBaV2A7Z
    mwc-random-0.15.2.0-7sfKS9N01akD1OE2VBvNl9
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    primitive-0.9.1.0-4gbRHMYHSCF2lptKn8Ww53
    random-1.2.1.3-53eBMyqCn4j5j5sTN6ACJa
    vector-0.13.2.0-E9z8CkzpYQwAFSNyB7dwgD
    vector-algorithms-0.9.1.0-2noFDla3no5F8A9qqpa699
    vector-binary-instances-0.2.5.2-bJhHBCLVR9JlLYKco84qL
    vector-th-unbox-0.2.2-70BjnRjX1NlL3HyDPSlifH

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statistics-0.16.3.0-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 statistics
version:              0.16.3.0
visibility:           public
id:                   statistics-0.16.3.0-BYnmTSCGWnk1XjGoisVvrD
key:                  statistics-0.16.3.0-BYnmTSCGWnk1XjGoisVvrD
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/haskell/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
      distributions.  (There are dozens of exotic distributions in use;
      we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
      estimation, histograms, bootstrap methods, significance testing,
      and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
      samples.

category:             Math, Statistics
abi:                  b181d90911e61cd2711808c4dfa53764
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Lognormal
    Statistics.Distribution.NegativeBinomial
    Statistics.Distribution.Normal Statistics.Distribution.Poisson
    Statistics.Distribution.StudentT Statistics.Distribution.Transform
    Statistics.Distribution.Uniform Statistics.Distribution.Weibull
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.ChiSquared
    Statistics.Test.KolmogorovSmirnov Statistics.Test.KruskalWallis
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/statistics-0.16.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-statistics
hs-libraries:         HSstatistics-0.16.3.0-BYnmTSCGWnk1XjGoisVvrD
depends:
    aeson-2.1.2.1-AErwMfn2r5g1Pc6FekWoJb
    async-2.2.5-H08LAofdMrZAVDKKqADI6w base-4.17.2.1 binary-0.8.9.1
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi deepseq-1.4.8.0
    dense-linear-algebra-0.1.0.0-GVBiq2niXzJAeFO9dEduPK
    math-functions-0.3.4.4-7ESDaarFEQE9v4MR7JQ1u6
    mwc-random-0.15.2.0-Cp8pYRGgzb6CqeqRM8mnd7
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    primitive-0.9.1.0-IYGvfPhp8bDLAkMykHY1iR
    random-1.2.1.3-9Bk1Rk8uHFTJVqAMIpxjnc
    vector-0.13.2.0-ALyKXv7XVpOIl9EVBdgwIc
    vector-algorithms-0.9.1.0-ClCJMFYn7mHHTRfF5ufOk6
    vector-binary-instances-0.2.5.2-A0gwg3ZolRRKbP8XDv0o6A
    vector-th-unbox-0.2.2-7ixx6bfHKYy6TIbXVM6ITN

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
